@@ -1,4 +1,4 @@
-"""yolk
+"""yolk.
 
 Author: Rob Cakebread <cakebread at gmail>
 
@@ -6,4 +6,4 @@ License  : BSD
 
 """
 
-__version__ = '0.6.2'
+__version__ = '0.7'
