@@ -1,7 +1,7 @@
 # pylint: disable-msg=W0613,W0612,W0212,W0511,R0912,C0322,W0704
 # W0511 = XXX (my own todo's)
 
-"""cli
+"""cli.
 
 Desc: Command-line tool for listing Python packages installed by setuptools,
       package metadata, package dependencies, and querying The Cheese Shop
@@ -24,7 +24,6 @@ import sys
 import optparse
 import pkg_resources
 import webbrowser
-import logging
 import platform
 if platform.python_version().startswith('2'):
     from xmlrpclib import Fault as XMLRPCFault
@@ -44,7 +43,7 @@ from yolk.utils import run_command, command_successful
 from yolk.__init__ import __version__ as VERSION
 
 
-class StdOut:
+class StdOut(object):
 
     """Filter stdout or stderr from specific modules So far this is just used
     for pkg_resources."""
@@ -70,9 +69,9 @@ class StdOut:
     def write(self, inline):
         """Write a line to stdout if it isn't in a blacklist.
 
-        Try to get the name of the calling module to see if we want
-        to filter it. If there is no calling module, use current
-        frame in case there's a traceback before there is any calling module
+        Try to get the name of the calling module to see if we want to
+        filter it. If there is no calling module, use current frame in
+        case there's a traceback before there is any calling module
 
         """
         frame = inspect.currentframe().f_back
@@ -102,7 +101,6 @@ class Yolk(object):
         self.all_versions = []
         self.pkg_spec = []
         self.options = None
-        self.logger = logging.getLogger('yolk')
 
         # Squelch output from setuptools
         # Add future offenders to this list.
@@ -127,29 +125,11 @@ class Yolk(object):
             plugin.configure(self.options, None)
             if plugin.enabled:
                 if not hasattr(plugin, method):
-                    self.logger.warn(
-                        'Error: plugin has no method: %s' % method)
                     plugin = None
                 else:
                     all_plugins.append(plugin)
         return all_plugins
 
-    def set_log_level(self):
-        """Set log level according to command-line options.
-
-        @returns: logger object
-
-        """
-
-        if self.options.debug:
-            self.logger.setLevel(logging.DEBUG)
-        elif self.options.quiet:
-            self.logger.setLevel(logging.ERROR)
-        else:
-            self.logger.setLevel(logging.INFO)
-        self.logger.addHandler(logging.StreamHandler())
-        return self.logger
-
     def run(self):
         """Perform actions based on CLI options.
 
@@ -158,7 +138,6 @@ class Yolk(object):
         """
         opt_parser = setup_opt_parser()
         (self.options, remaining_args) = opt_parser.parse_args()
-        logger = self.set_log_level()
 
         pkg_spec = validate_pypi_opts(opt_parser)
         if not pkg_spec:
@@ -189,10 +168,12 @@ class Yolk(object):
             # XXX: We should return 2 here if we couldn't create xmlrpc server
 
         if pkg_spec:
-            (self.project_name, self.version, self.all_versions) = \
-                self.parse_pkg_ver(want_installed)
+            (self.project_name,
+             self.version,
+             self.all_versions) = self.parse_pkg_ver(want_installed)
             if want_installed and not self.project_name:
-                logger.error('%s is not installed.' % pkg_spec)
+                print('{} is not installed'.format(pkg_spec),
+                      file=sys.stderr)
                 return 1
 
         # I could prefix all these with 'cmd_' and the methods also
@@ -242,14 +223,16 @@ class Yolk(object):
         else:
             # Check for every installed package
             pkg_list = get_pkglist()
-        found = None
 
         from multiprocessing.pool import ThreadPool
+
         def worker_function(pkg):
-            for (dist, active) in dists.get_distributions("all", pkg,
+            for (dist, active) in dists.get_distributions(
+                    'all', pkg,
                     dists.get_highest_installed(pkg)):
-                (project_name, versions) = \
-                        self.pypi.query_versions_pypi(dist.project_name)
+
+                (project_name, versions) = self.pypi.query_versions_pypi(
+                    dist.project_name)
             return (pkg, dist, project_name, versions)
 
         import multiprocessing
@@ -265,16 +248,14 @@ class Yolk(object):
                 newest = get_highest_version(versions)
                 if newest != dist.version:
                     # We may have newer than what PyPI knows about.
-                    if pkg_resources.parse_version(dist.version) < \
-                        pkg_resources.parse_version(newest):
-                        found = True
-                        print(" %s %s (%s)" %
-                              (project_name, dist.version, newest))
+                    if (
+                        pkg_resources.parse_version(dist.version) <
+                        pkg_resources.parse_version(newest)
+                    ):
+                        print(' {} {} ({})'.format(project_name,
+                                                   dist.version,
+                                                   newest))
 
-        if not found and self.project_name:
-            self.logger.info('You have the latest version installed.')
-        elif not found:
-            self.logger.info('No newer packages found at The Cheese Shop')
         return 0
 
     def show_distributions(self, show):
@@ -324,16 +305,17 @@ class Yolk(object):
             results = True
         if not results and self.project_name:
             if self.version:
-                pkg_spec = '%s==%s' % (self.project_name, self.version)
+                pkg_spec = '{}=={}'.format(self.project_name, self.version)
             else:
-                pkg_spec = '%s' % self.project_name
+                pkg_spec = self.project_name
             if show == 'all':
-                self.logger.error('There are no versions of %s installed.'
-                                  % pkg_spec)
+                print('There are no versions of {} installed'.format(pkg_spec),
+                      file=sys.stderr)
             else:
-                self.logger.error('There are no %s versions of %s installed.'
-                                  %
-                                 (show, pkg_spec))
+                print(
+                    'There are no {} versions of {} installed'.format(
+                        show, pkg_spec),
+                    file=sys.stderr)
             return 2
         elif show == 'all' and results and self.options.fields:
             print("Versions with '*' are non-active.")
@@ -378,15 +360,16 @@ class Yolk(object):
                 active_status = 'non-active'
         if develop:
             if fields:
-                development_status = '! (%s)' % develop
+                development_status = '! ({})'.format(develop)
             else:
-                development_status = 'development (%s)' % develop
+                development_status = 'development ({})'.format(develop)
         else:
             development_status = installed_by
-        status = '%s %s' % (active_status, development_status)
+        status = '{} {}'.format(active_status, development_status)
         if fields:
-            print('%s (%s)%s %s' % (metadata['Name'], version, active_status,
-                                    development_status))
+            print(
+                '{} ({}){} {}'.format(metadata['Name'], version, active_status,
+                                      development_status))
         else:
             # Need intelligent justification
             print(metadata['Name'].ljust(15) + ' - ' + version.ljust(12) +
@@ -396,13 +379,13 @@ class Yolk(object):
             fields = [s.lower() for s in fields]
             for field in metadata.keys():
                 if field.lower() in fields:
-                    print('    %s: %s' % (field, metadata[field]))
+                    print('    {}: {}'.format(field, metadata[field]))
             print()
         elif show_metadata:
             # Print all available metadata fields
             for field in metadata.keys():
                 if field != 'Name' and field != 'Summary':
-                    print('    %s: %s' % (field, metadata[field]))
+                    print('    {}: {}'.format(field, metadata[field]))
 
     def show_deps(self):
         """Show dependencies for package(s)
@@ -420,8 +403,11 @@ class Yolk(object):
             i = len(list(pkg._dep_map.values())[0])
             if i:
                 while i:
-                    if not self.version or self.version and \
-                            pkg.version == self.version:
+                    if (
+                        not self.version or
+                        self.version and
+                        pkg.version == self.version
+                    ):
                         if self.version and i == len(list(
                                 pkg._dep_map.values())[0]):
                             print(pkg.project_name, pkg.version)
@@ -429,8 +415,6 @@ class Yolk(object):
                             pkg._dep_map.values())[0][i - 1]))
                     i -= 1
             else:
-                self.logger.info(
-                    'No dependency information was supplied with the package.')
                 return 1
         return 0
 
@@ -442,24 +426,25 @@ class Yolk(object):
         """
         hours = self.options.show_pypi_changelog
         if not hours.isdigit():
-            self.logger.error('Error: You must supply an integer.')
+            print('You must supply an integer',
+                  file=sys.stderr)
             return 1
 
         try:
             changelog = self.pypi.changelog(int(hours))
         except XMLRPCFault as err_msg:
-            self.logger.error(err_msg)
-            self.logger.error("ERROR: Couldn't retrieve changelog.")
+            print(err_msg, file=sys.stderr)
+            print("Couldn't retrieve changelog", file=sys.stderr)
             return 1
 
         last_pkg = ''
         for entry in changelog:
             pkg = entry[0]
             if pkg != last_pkg:
-                print('%s %s\n\t%s' % (entry[0], entry[1], entry[3]))
+                print('{} {}\n\t{}'.format(entry[0], entry[1], entry[3]))
                 last_pkg = pkg
             else:
-                print('\t%s' % entry[3])
+                print('\t{}'.format(entry[3]))
 
         return 0
 
@@ -472,17 +457,17 @@ class Yolk(object):
         try:
             hours = int(self.options.show_pypi_releases)
         except ValueError:
-            self.logger.error('ERROR: You must supply an integer.')
+            print('You must supply an integer', file=sys.stderr)
             return 1
         try:
             latest_releases = self.pypi.updated_releases(hours)
         except XMLRPCFault as err_msg:
-            self.logger.error(err_msg)
-            self.logger.error("ERROR: Couldn't retrieve latest releases.")
+            print(err_msg, file=sys.stderr)
+            print("Couldn't retrieve latest releases.", file=sys.stderr)
             return 1
 
         for release in latest_releases:
-            print('%s %s' % (release[0], release[1]))
+            print('{} {}'.format(release[0], release[1]))
         return 0
 
     def show_download_links(self):
@@ -529,20 +514,13 @@ class Yolk(object):
         """
 
         if version == 'dev':
-            pkg_type = 'subversion'
             source = True
-        elif source:
-            pkg_type = 'source'
-        else:
-            pkg_type = 'egg'
 
         # Use setuptools monkey-patch to grab url
         url = get_download_uri(self.project_name, version, source,
                                self.options.pypi_index)
         if url:
-            print('%s' % url)
-        else:
-            self.logger.info('No download URL found for %s' % pkg_type)
+            print('{}'.format(url))
 
     def fetch(self):
         """Download a package.
@@ -561,9 +539,10 @@ class Yolk(object):
                 directory = self.project_name + '_svn'
                 return self.fetch_svn(svn_uri, directory)
             else:
-                self.logger.error(
-                    'ERROR: No subversion repository found for %s' %
-                    self.project_name)
+                print(
+                    'No subversion repository found for {}'.format(
+                        self.project_name),
+                    file=sys.stderr)
                 return 1
         elif self.options.file_type == 'source':
             source = True
@@ -574,8 +553,8 @@ class Yolk(object):
         if uri:
             return self.fetch_uri(directory, uri)
         else:
-            self.logger.error('No %s URI found for package: %s ' %
-                             (self.options.file_type, self.project_name))
+            print('No {} URI found for package: {}'.format(
+                (self.options.file_type, self.project_name)))
             return 1
 
     def fetch_uri(self, directory, uri):
@@ -593,23 +572,24 @@ class Yolk(object):
         """
         filename = os.path.basename(urlparse(uri)[2])
         if os.path.exists(filename):
-            self.logger.error('ERROR: File exists: ' + filename)
+            print('File exists: ' + filename, file=sys.stderr)
             return 1
 
         try:
             downloaded_filename, headers = urlretrieve(uri, filename)
-            self.logger.info('Downloaded ./' + filename)
         except IOError as err_msg:
-            self.logger.error('Error downloading package %s from URL %s'
-                              % (filename, uri))
-            self.logger.error(str(err_msg))
+            print(
+                'Error downloading package {} from URL {}'.format(
+                    filename, uri),
+                file=sys.stderr)
+            print(str(err_msg), file=sys.stderr)
             return 1
 
         if 'text/html' in headers:
             dfile = open(downloaded_filename)
             if re.search('404 Not Found', ''.join(dfile.readlines())):
                 dfile.close()
-                self.logger.error("'404 Not Found' error")
+                print("'404 Not Found' error", file=sys.stderr)
                 return 1
             dfile.close()
         return 0
@@ -627,25 +607,22 @@ class Yolk(object):
 
         """
         if not command_successful('svn --version'):
-            self.logger.error('ERROR: Do you have subversion installed?')
+            print('Do you have subversion installed?', file=sys.stderr)
             return 1
         if os.path.exists(directory):
-            self.logger.error('ERROR: Checkout directory exists - %s'
-                              % directory)
+            print(
+                'Checkout directory exists - {}'.format(directory),
+                file=sys.stderr)
             return 1
         try:
             os.mkdir(directory)
         except OSError as err_msg:
-            self.logger.error('ERROR: ' + str(err_msg))
+            print('' + str(err_msg), file=sys.stderr)
             return 1
         cwd = os.path.realpath(os.curdir)
         os.chdir(directory)
-        self.logger.info('Doing subversion checkout for %s' % svn_uri)
-        status, output = run_command('/usr/bin/svn co %s' % svn_uri)
-        self.logger.info(output)
+        status, _ = run_command('/usr/bin/svn co {}'.format(svn_uri))
         os.chdir(cwd)
-        self.logger.info("subversion checkout is in directory './%s'"
-                         % directory)
         return 0
 
     def browse_website(self, browser=None):
@@ -660,10 +637,7 @@ class Yolk(object):
         if len(self.all_versions):
             metadata = self.pypi.release_data(self.project_name,
                                               self.all_versions[0])
-            self.logger.debug('DEBUG: browser: %s' % browser)
             if 'home_page' in metadata:
-                self.logger.info('Launching browser: %s'
-                                 % metadata['home_page'])
                 if browser == 'konqueror':
                     browser = webbrowser.Konqueror()
                 else:
@@ -671,7 +645,7 @@ class Yolk(object):
                     browser.open(metadata['home_page'], 2)
                 return 0
 
-        self.logger.error('No homepage URL found.')
+        print('No homepage URL found', file=sys.stderr)
         return 1
 
     def query_metadata_pypi(self):
@@ -691,7 +665,7 @@ class Yolk(object):
             for key in metadata.keys():
                 if not self.options.fields or (self.options.fields and
                                                self.options.fields == key):
-                    print('%s: %s' % (key, metadata[key]))
+                    print('{}: {}'.format(key, metadata[key]))
         return 0
 
     def versions_available(self):
@@ -706,11 +680,13 @@ class Yolk(object):
             print_pkg_versions(self.project_name, self.all_versions)
         else:
             if self.version:
-                self.logger.error('No package found for version %s'
-                                  % self.version)
+                print(
+                    'No package found for version {}'.format(self.version),
+                    file=sys.stderr)
             else:
-                self.logger.error(
-                    'No package found for %s' % self.project_name)
+                print(
+                    'No package found for {}'.format(self.project_name),
+                    file=sys.stderr)
             return 1
         return 0
 
@@ -730,8 +706,7 @@ class Yolk(object):
 
         """
 
-        usage = \
-            """You can search PyPI by the following:
+        usage = """You can search PyPI by the following:
      name
      version
      author
@@ -751,7 +726,7 @@ class Yolk(object):
           """
 
         if not spec:
-            self.logger.error(usage)
+            print(usage, file=sys.stderr)
             return (None, None)
 
         try:
@@ -776,7 +751,7 @@ class Yolk(object):
             if second:
                 spec[key2] = term2
         except:
-            self.logger.error(usage)
+            print(usage, file=sys.stderr)
             spec = operator = None
         return (spec, operator)
 
@@ -809,10 +784,10 @@ class Yolk(object):
                 summary = pkg['summary'].encode('utf-8')
             else:
                 summary = ''
-            print("""%s (%s):
-        %s
-    """ % (pkg['name'].encode('utf-8'), pkg['version'],
-           summary))
+            print("""{} ({}):
+        {}
+    """.format(pkg['name'].encode('utf-8'), pkg['version'],
+               summary))
         return 0
 
     def show_entry_map(self):
@@ -831,8 +806,10 @@ class Yolk(object):
             if entry_map:
                 pprinter.pprint(entry_map)
         except pkg_resources.DistributionNotFound:
-            self.logger.error('Distribution not found: %s'
-                              % self.options.show_entry_map)
+            print(
+                'Distribution not found: {}'.format(
+                    self.options.show_entry_map),
+                file=sys.stderr)
             return 1
         return 0
 
@@ -850,26 +827,23 @@ class Yolk(object):
             try:
                 plugin = entry_point.load()
                 print(plugin.__module__)
-                print('   %s' % entry_point)
+                print('   {}'.format(entry_point))
                 if plugin.__doc__:
                     print(plugin.__doc__)
                 print()
             except ImportError:
                 pass
         if not found:
-            self.logger.error('No entry points found for %s'
-                              % self.options.show_entry_points)
+            print(
+                'No entry points found for {}'.format(
+                    self.options.show_entry_points),
+                file=sys.stderr)
             return 1
         return 0
 
     def yolk_version(self):
-        """Show yolk's version.
-
-        @returns: 0
-
-        """
-        self.logger.info('yolk version %s' % VERSION)
-        return 0
+        """Show yolk's version."""
+        print('yolk {}'.format(VERSION))
 
     def parse_pkg_ver(self, want_installed):
         """Return tuple with project_name and version from CLI args If the user
@@ -897,13 +871,13 @@ class Yolk(object):
             dists = Distributions()
             project_name = dists.case_sensitive_name(project_name)
         else:
-            (project_name, all_versions) = \
-                self.pypi.query_versions_pypi(project_name)
+            (project_name, all_versions) = self.pypi.query_versions_pypi(
+                project_name)
 
             if not len(all_versions):
-                msg = "I'm afraid we have no '%s' at " % project_name
+                msg = "I'm afraid we have no '{}' at ".format(project_name)
                 msg += 'The Cheese Shop. A little Red Leicester, perhaps?'
-                self.logger.error(msg)
+                print(msg, file=sys.stderr)
                 sys.exit(2)
         return (project_name, version, all_versions)
 
@@ -935,12 +909,12 @@ def setup_opt_parser():
     group_local = optparse.OptionGroup(
         opt_parser,
         'Query installed Python packages',
-        "The following options show information about installed Python "
-        "packages. Activated packages are normal packages on sys.path that "
-        "can be imported. Non-activated packages need "
+        'The following options show information about installed Python '
+        'packages. Activated packages are normal packages on sys.path that '
+        'can be imported. Non-activated packages need '
         "'pkg_resources.require()' before they can be imported, such as "
         "packages installed with 'easy_install --multi-version'. PKG_SPEC can "
-        "be either a package name or package name and version e.g. Paste==0.9")
+        'be either a package name or package name and version e.g. Paste==0.9')
 
     group_local.add_option(
         '-l', '--list', action='store_true', dest=
@@ -1004,7 +978,7 @@ def setup_opt_parser():
         metavar='PKG_SPEC', dest='show_download_links',
         default=False,
         help="Show download URL's for package listed on PyPI. Use with -T to "
-             "specify egg, source etc.")
+             'specify egg, source etc.')
 
     group_pypi.add_option(
         '-F', '--fetch-package', action='store',
@@ -1055,7 +1029,7 @@ def setup_opt_parser():
                           'store', dest='versions_available',
                           default=False, metavar='PKG_SPEC',
                           help='Show available versions for given package ' +
-                          'listed on PyPI.')
+                               'listed on PyPI.')
     opt_parser.add_option_group(group_local)
     opt_parser.add_option_group(group_pypi)
     # add opts from plugins
@@ -1076,7 +1050,7 @@ def print_pkg_versions(project_name, versions):
 
     """
     for ver in versions:
-        print('%s %s' % (project_name, ver))
+        print('{} {}'.format(project_name, ver))
 
 
 def validate_pypi_opts(opt_parser):
