@@ -1,4 +1,4 @@
-"""pypi
+"""pypi.
 
 Desc: Library for getting information about Python packages by querying
       The CheeseShop (PYPI a.k.a. Python Package Index).
@@ -23,7 +23,6 @@ else:
     import urllib.request as urllib2
 import os
 import time
-import logging
 
 from yolk.utils import get_yolk_dir
 
@@ -82,7 +81,7 @@ def check_proxy_setting():
         return
 
     if not http_proxy.startswith('http://'):
-        match = re.match('(http://)?([-_\.A-Za-z]+):(\d+)', http_proxy)
+        match = re.match(r'(http://)?([-_\.A-Za-z]+):(\d+)', http_proxy)
         os.environ['HTTP_PROXY'] = 'http://%s:%s' % (match.group(2),
                                                      match.group(3))
     return
@@ -103,7 +102,6 @@ class CheeseShop(object):
         self.pkg_cache_file = self.get_pkg_cache_file()
         self.last_sync_file = self.get_last_sync_file()
         self.pkg_list = None
-        self.logger = logging.getLogger('yolk')
         self.get_cache()
 
     def get_cache(self):
@@ -119,8 +117,6 @@ class CheeseShop(object):
         try:
             self.pkg_list = self.query_cached_package_list()
         except (IOError, ValueError):
-            self.logger.debug(
-                'DEBUG: Fetching package list cache from PyPi...')
             self.fetch_pkg_list(True)
 
     def get_last_sync_file(self):
@@ -135,12 +131,8 @@ class CheeseShop(object):
             debug = 1
         else:
             debug = 0
-        try:
-            return xmlrpclib.Server(XML_RPC_SERVER, transport=ProxyTransport(),
-                                    verbose=debug)
-        except IOError:
-            self.logger("ERROR: Can't connect to XML-RPC server: %s"
-                        % XML_RPC_SERVER)
+        return xmlrpclib.Server(XML_RPC_SERVER, transport=ProxyTransport(),
+                                verbose=debug)
 
     def get_pkg_cache_file(self):
         """Returns filename of pkg cache."""
@@ -149,17 +141,13 @@ class CheeseShop(object):
     def query_versions_pypi(self, package_name):
         """Fetch list of available versions for a package from PyPI."""
         if not package_name in self.pkg_list:
-            self.logger.debug('Package %s not in cache, querying PyPI...'
-                              % package_name)
             self.fetch_pkg_list()
         # I have to set version=[] for edge cases like "Magic file extensions"
         # but I'm not sure why this happens. It's included with Python or
         # because it has a space in it's name?
         versions = []
         for pypi_pkg in self.pkg_list:
-            if pypi_pkg.lower() == package_name.lower():
-                if self.debug:
-                    self.logger.debug('DEBUG: %s' % package_name)
+            if normalize(pypi_pkg) == normalize(package_name):
                 versions = self.package_releases(pypi_pkg)
                 package_name = pypi_pkg
                 break
@@ -167,14 +155,11 @@ class CheeseShop(object):
 
     def query_cached_package_list(self):
         """Return list of cached package names from PYPI."""
-        if self.debug:
-            self.logger.debug('DEBUG: reading cache file')
         with open(self.pkg_cache_file, 'r') as input_file:
             return ast.literal_eval(input_file.read())
 
     def fetch_pkg_list(self, ignore_cache=False):
         """Fetch and cache master list of package names from PYPI."""
-        self.logger.debug('DEBUG: Fetching package name list from PyPI')
         if (
             not ignore_cache and
             os.path.exists(self.pkg_cache_file) and
@@ -220,13 +205,10 @@ class CheeseShop(object):
 
     def package_releases(self, package_name):
         """Query PYPI via XMLRPC interface for a pkg's available versions."""
-        if self.debug:
-            self.logger.debug('DEBUG: querying PyPI for versions of '
-                              + package_name)
         return self.xmlrpc.package_releases(package_name)
 
     def get_download_urls(self, package_name, version='', pkg_type='all'):
-        """Query PyPI for pkg download URI for a package"""
+        """Query PyPI for pkg download URI for a package."""
         if version:
             versions = [version]
         else:
@@ -299,3 +281,8 @@ def get_seconds(hours):
 
     """
     return int(time.time() - (60 * 60) * hours)
+
+
+def normalize(name):
+    """Return normalized name."""
+    return name.lower().replace('_', '-')
